/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.builder.component.dsl;

import javax.annotation.Generated;
import org.apache.camel.Component;
import org.apache.camel.builder.component.AbstractComponentBuilder;
import org.apache.camel.builder.component.ComponentBuilder;
import org.apache.camel.component.jslt.JsltComponent;

/**
 * Query or transform JSON payloads using an JSLT.
 * 
 * Generated by camel-package-maven-plugin - do not edit this file!
 */
@Generated("org.apache.camel.maven.packaging.ComponentDslMojo")
public interface JsltComponentBuilderFactory {

    /**
     * JSLT (camel-jslt)
     * Query or transform JSON payloads using an JSLT.
     * 
     * Category: transformation
     * Since: 3.1
     * Maven coordinates: org.apache.camel:camel-jslt
     * 
     * @return the dsl builder
     */
    static JsltComponentBuilder jslt() {
        return new JsltComponentBuilderImpl();
    }

    /**
     * Builder for the JSLT component.
     */
    interface JsltComponentBuilder extends ComponentBuilder<JsltComponent> {
        /**
         * Whether to allow to use resource template from header or not (default
         * false). Enabling this allows to specify dynamic templates via message
         * header. However this can be seen as a potential security
         * vulnerability if the header is coming from a malicious user, so use
         * this with care.
         * 
         * The option is a: &lt;code&gt;boolean&lt;/code&gt; type.
         * 
         * Default: false
         * Group: producer
         * 
         * @param allowTemplateFromHeader the value to set
         * @return the dsl builder
         */
        default JsltComponentBuilder allowTemplateFromHeader(
                boolean allowTemplateFromHeader) {
            doSetProperty("allowTemplateFromHeader", allowTemplateFromHeader);
            return this;
        }
        /**
         * Whether the producer should be started lazy (on the first message).
         * By starting lazy you can use this to allow CamelContext and routes to
         * startup in situations where a producer may otherwise fail during
         * starting and cause the route to fail being started. By deferring this
         * startup to be lazy then the startup failure can be handled during
         * routing messages via Camel's routing error handlers. Beware that when
         * the first message is processed then creating and starting the
         * producer may take a little time and prolong the total processing time
         * of the processing.
         * 
         * The option is a: &lt;code&gt;boolean&lt;/code&gt; type.
         * 
         * Default: false
         * Group: producer
         * 
         * @param lazyStartProducer the value to set
         * @return the dsl builder
         */
        default JsltComponentBuilder lazyStartProducer(boolean lazyStartProducer) {
            doSetProperty("lazyStartProducer", lazyStartProducer);
            return this;
        }
        /**
         * Whether autowiring is enabled. This is used for automatic autowiring
         * options (the option must be marked as autowired) by looking up in the
         * registry to find if there is a single instance of matching type,
         * which then gets configured on the component. This can be used for
         * automatic configuring JDBC data sources, JMS connection factories,
         * AWS Clients, etc.
         * 
         * The option is a: &lt;code&gt;boolean&lt;/code&gt; type.
         * 
         * Default: true
         * Group: advanced
         * 
         * @param autowiredEnabled the value to set
         * @return the dsl builder
         */
        default JsltComponentBuilder autowiredEnabled(boolean autowiredEnabled) {
            doSetProperty("autowiredEnabled", autowiredEnabled);
            return this;
        }
        /**
         * JSLT can be extended by plugging in functions written in Java.
         * 
         * The option is a:
         * &lt;code&gt;java.util.Collection&amp;lt;com.schibsted.spt.data.jslt.Function&amp;gt;&lt;/code&gt; type.
         * 
         * Group: advanced
         * 
         * @param functions the value to set
         * @return the dsl builder
         */
        default JsltComponentBuilder functions(
                java.util.Collection<com.schibsted.spt.data.jslt.Function> functions) {
            doSetProperty("functions", functions);
            return this;
        }
        /**
         * JSLT can be extended by plugging in a custom jslt object filter.
         * 
         * The option is a:
         * &lt;code&gt;com.schibsted.spt.data.jslt.filters.JsonFilter&lt;/code&gt; type.
         * 
         * Group: advanced
         * 
         * @param objectFilter the value to set
         * @return the dsl builder
         */
        default JsltComponentBuilder objectFilter(
                com.schibsted.spt.data.jslt.filters.JsonFilter objectFilter) {
            doSetProperty("objectFilter", objectFilter);
            return this;
        }
    }

    class JsltComponentBuilderImpl
            extends
                AbstractComponentBuilder<JsltComponent>
            implements
                JsltComponentBuilder {
        @Override
        protected JsltComponent buildConcreteComponent() {
            return new JsltComponent();
        }
        @Override
        protected boolean setPropertyOnComponent(
                Component component,
                String name,
                Object value) {
            switch (name) {
            case "allowTemplateFromHeader": ((JsltComponent) component).setAllowTemplateFromHeader((boolean) value); return true;
            case "lazyStartProducer": ((JsltComponent) component).setLazyStartProducer((boolean) value); return true;
            case "autowiredEnabled": ((JsltComponent) component).setAutowiredEnabled((boolean) value); return true;
            case "functions": ((JsltComponent) component).setFunctions((java.util.Collection) value); return true;
            case "objectFilter": ((JsltComponent) component).setObjectFilter((com.schibsted.spt.data.jslt.filters.JsonFilter) value); return true;
            default: return false;
            }
        }
    }
}