/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.builder.component.dsl;

import javax.annotation.Generated;
import org.apache.camel.Component;
import org.apache.camel.builder.component.AbstractComponentBuilder;
import org.apache.camel.builder.component.ComponentBuilder;
import org.apache.camel.component.vertx.VertxComponent;

/**
 * Send and receive messages to/from Vert.x Event Bus.
 * 
 * Generated by camel-package-maven-plugin - do not edit this file!
 */
@Generated("org.apache.camel.maven.packaging.ComponentDslMojo")
public interface VertxComponentBuilderFactory {

    /**
     * Vert.x (camel-vertx)
     * Send and receive messages to/from Vert.x Event Bus.
     * 
     * Category: eventbus,reactive
     * Since: 2.12
     * Maven coordinates: org.apache.camel:camel-vertx
     * 
     * @return the dsl builder
     */
    static VertxComponentBuilder vertx() {
        return new VertxComponentBuilderImpl();
    }

    /**
     * Builder for the Vert.x component.
     */
    interface VertxComponentBuilder extends ComponentBuilder<VertxComponent> {
        /**
         * Hostname for creating an embedded clustered EventBus.
         * 
         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
         * 
         * Group: common
         * 
         * @param host the value to set
         * @return the dsl builder
         */
        default VertxComponentBuilder host(java.lang.String host) {
            doSetProperty("host", host);
            return this;
        }
        /**
         * Port for creating an embedded clustered EventBus.
         * 
         * The option is a: &lt;code&gt;int&lt;/code&gt; type.
         * 
         * Group: common
         * 
         * @param port the value to set
         * @return the dsl builder
         */
        default VertxComponentBuilder port(int port) {
            doSetProperty("port", port);
            return this;
        }
        /**
         * Timeout in seconds to wait for clustered Vertx EventBus to be ready.
         * The default value is 60.
         * 
         * The option is a: &lt;code&gt;int&lt;/code&gt; type.
         * 
         * Default: 60
         * Group: common
         * 
         * @param timeout the value to set
         * @return the dsl builder
         */
        default VertxComponentBuilder timeout(int timeout) {
            doSetProperty("timeout", timeout);
            return this;
        }
        /**
         * To use the given vertx EventBus instead of creating a new embedded
         * EventBus.
         * 
         * The option is a: &lt;code&gt;io.vertx.core.Vertx&lt;/code&gt; type.
         * 
         * Group: common
         * 
         * @param vertx the value to set
         * @return the dsl builder
         */
        default VertxComponentBuilder vertx(io.vertx.core.Vertx vertx) {
            doSetProperty("vertx", vertx);
            return this;
        }
        /**
         * Options to use for creating vertx.
         * 
         * The option is a: &lt;code&gt;io.vertx.core.VertxOptions&lt;/code&gt;
         * type.
         * 
         * Group: common
         * 
         * @param vertxOptions the value to set
         * @return the dsl builder
         */
        default VertxComponentBuilder vertxOptions(
                io.vertx.core.VertxOptions vertxOptions) {
            doSetProperty("vertxOptions", vertxOptions);
            return this;
        }
        /**
         * Allows for bridging the consumer to the Camel routing Error Handler,
         * which mean any exceptions occurred while the consumer is trying to
         * pickup incoming messages, or the likes, will now be processed as a
         * message and handled by the routing Error Handler. By default the
         * consumer will use the org.apache.camel.spi.ExceptionHandler to deal
         * with exceptions, that will be logged at WARN or ERROR level and
         * ignored.
         * 
         * The option is a: &lt;code&gt;boolean&lt;/code&gt; type.
         * 
         * Default: false
         * Group: consumer
         * 
         * @param bridgeErrorHandler the value to set
         * @return the dsl builder
         */
        default VertxComponentBuilder bridgeErrorHandler(
                boolean bridgeErrorHandler) {
            doSetProperty("bridgeErrorHandler", bridgeErrorHandler);
            return this;
        }
        /**
         * Whether the producer should be started lazy (on the first message).
         * By starting lazy you can use this to allow CamelContext and routes to
         * startup in situations where a producer may otherwise fail during
         * starting and cause the route to fail being started. By deferring this
         * startup to be lazy then the startup failure can be handled during
         * routing messages via Camel's routing error handlers. Beware that when
         * the first message is processed then creating and starting the
         * producer may take a little time and prolong the total processing time
         * of the processing.
         * 
         * The option is a: &lt;code&gt;boolean&lt;/code&gt; type.
         * 
         * Default: false
         * Group: producer
         * 
         * @param lazyStartProducer the value to set
         * @return the dsl builder
         */
        default VertxComponentBuilder lazyStartProducer(
                boolean lazyStartProducer) {
            doSetProperty("lazyStartProducer", lazyStartProducer);
            return this;
        }
        /**
         * Whether autowiring is enabled. This is used for automatic autowiring
         * options (the option must be marked as autowired) by looking up in the
         * registry to find if there is a single instance of matching type,
         * which then gets configured on the component. This can be used for
         * automatic configuring JDBC data sources, JMS connection factories,
         * AWS Clients, etc.
         * 
         * The option is a: &lt;code&gt;boolean&lt;/code&gt; type.
         * 
         * Default: true
         * Group: advanced
         * 
         * @param autowiredEnabled the value to set
         * @return the dsl builder
         */
        default VertxComponentBuilder autowiredEnabled(boolean autowiredEnabled) {
            doSetProperty("autowiredEnabled", autowiredEnabled);
            return this;
        }
        /**
         * To use a custom VertxFactory implementation.
         * 
         * The option is a:
         * &lt;code&gt;io.vertx.core.impl.VertxBuilder&lt;/code&gt; type.
         * 
         * Group: advanced
         * 
         * @param vertxFactory the value to set
         * @return the dsl builder
         */
        default VertxComponentBuilder vertxFactory(
                io.vertx.core.impl.VertxBuilder vertxFactory) {
            doSetProperty("vertxFactory", vertxFactory);
            return this;
        }
    }

    class VertxComponentBuilderImpl
            extends
                AbstractComponentBuilder<VertxComponent>
            implements
                VertxComponentBuilder {
        @Override
        protected VertxComponent buildConcreteComponent() {
            return new VertxComponent();
        }
        @Override
        protected boolean setPropertyOnComponent(
                Component component,
                String name,
                Object value) {
            switch (name) {
            case "host": ((VertxComponent) component).setHost((java.lang.String) value); return true;
            case "port": ((VertxComponent) component).setPort((int) value); return true;
            case "timeout": ((VertxComponent) component).setTimeout((int) value); return true;
            case "vertx": ((VertxComponent) component).setVertx((io.vertx.core.Vertx) value); return true;
            case "vertxOptions": ((VertxComponent) component).setVertxOptions((io.vertx.core.VertxOptions) value); return true;
            case "bridgeErrorHandler": ((VertxComponent) component).setBridgeErrorHandler((boolean) value); return true;
            case "lazyStartProducer": ((VertxComponent) component).setLazyStartProducer((boolean) value); return true;
            case "autowiredEnabled": ((VertxComponent) component).setAutowiredEnabled((boolean) value); return true;
            case "vertxFactory": ((VertxComponent) component).setVertxFactory((io.vertx.core.impl.VertxBuilder) value); return true;
            default: return false;
            }
        }
    }
}